package main

import (
	"github.com/slimtoolkit/slim/pkg/app/sensor"
)

func main() {
	sensor.Run()
}
